pub struct Project {
pub timestamp: Duration,
pub path_buf: PathBuf,
}Fields
timestamp: Durationpath_buf: PathBufTrait Implementations
Sourceimpl Extend<Project> for Projects
impl Extend<Project> for Projects
Sourcefn extend<T>(&mut self, iter: T)where
T: IntoIterator<Item = Project>,
fn extend<T>(&mut self, iter: T)where
T: IntoIterator<Item = Project>,
Extends a collection with the contents of an iterator. Read more
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
Sourceimpl Ord for Project
impl Ord for Project
Sourceimpl PartialOrd for Project
impl PartialOrd for Project
impl Eq for Project
impl StructuralPartialEq for Project